==> in-1.0.0.tar.gz: in/src/Form/InSettingsForm.php <==
<?php

namespace Drupal\in\Form;

//use Drupal\Component\Uuid\UuidInterface;
use Drupal\Core\Asset\AssetDumperInterface;
use Drupal\Core\File\FileSystemInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\Core\State\StateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\in\InHelper;
use Drupal\in\InRenderer;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * The config form for the IN module.
 *
 * @package Drupal\in\Form
 */
class InSettingsForm extends FormBase {

  use StringTranslationTrait;

  /**
   * The state service.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * Drupal\Core\Messenger\MessengerInterface definition.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * An asset dumper.
   *
   * @var \Drupal\Core\Asset\AssetDumper
   */
  protected $dumper;

  /**
   * The IN renderer.
   *
   * @var \Drupal\in\InRenderer
   */
  protected $renderer;

  /**
   * Constructs a new InSettingsForm object.
   */
  public function __construct(
    StateInterface $state,
    MessengerInterface $messenger,
    InRenderer $renderer
  ) {
    $this->state = $state;
    $this->messenger = $messenger;
    $this->renderer = $renderer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('state'),
      $container->get('messenger'),
      $container->get('in.renderer')
    );
  }

  /**
   * {@inheritDoc}
   */
  public function getFormId() {
    return 'in_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
//    $this->state->set(InHelper::IN_STATE_TYPES, []);

    $items = $this->state->get(InHelper::IN_STATE_TYPES, []);

//    dd($items);

    if (count($items) > 0) {
      $form['settings'] = [
        '#type' => 'table',
        '#header' => [
          '',
          $this->t('Weight'),
          $this->t('Type label'),
          $this->t('Text color'),
          $this->t('Background color'),
          $this->t('Delete'),
        ],
        '#attributes' => [
          'id' => 'in-config-table',
        ],
        '#tabledrag' => [
          [
            'action' => 'order',
            'relationship' => 'sibling',
            'group' => 'draggable-weight',
          ],
        ],
      ];
    }
    else {
      $form['message'] = [
        '#type' => 'markup',
        '#markup' => '<p>' . t('There are no Important Notifications types yet. Just add a new one.') . '</p>',
      ];
    }

    foreach ($items as $i => $item) {
      $weight = $item['weight'];

      $form['settings'][$i] = [
        'data' => [],
      ];
      $form['settings'][$i]['#attributes']['class'] = ['draggable'];
      $form['settings'][$i]['weight'] = [
        '#type' => 'weight',
        '#title' => t('Weight'),
        '#title_display' => 'invisible',
        '#default_value' => $weight,
        '#attributes' => [
          'class' => [
            'draggable-weight'
          ]
        ],
      ];

      $form['settings'][$i]['wrap'] = [
        '#type' => 'container',
      ];
      $form['settings'][$i]['wrap']['label'] = [
        '#type' => 'textfield',
        '#title' => t('Label'),
        '#title_display' => 'invisible',
        '#required' => TRUE,
        '#default_value' => $item['label'],
      ];
      $form['settings'][$i]['wrap']['machine_name'] = [
        '#type' => 'machine_name',
        '#default_value' => $item['machine_name'],
//        '#disabled' => !isNew(), ??
        '#maxlength' => 64,
        '#description' => $this->t('A unique name for this item. It must only contain lowercase letters, numbers, and underscores.'),
        '#machine_name' => [
          'source' => [
            'settings',
            $i,
            'wrap',
            'label',
          ],
          'exists' => [
            $this,
            'exists',
          ],
        ],
      ];

      $form['settings'][$i]['color_text'] = [
        '#type' => 'color',
        '#title' => $this->t('Text color'),
        '#title_display' => 'invisible',
        '#default_value' => $item['color_text'] ?? '#000000',
      ];
      $form['settings'][$i]['color_back'] = [
        '#type' => 'color',
        '#title' => $this->t('Background color'),
        '#title_display' => 'invisible',
        '#default_value' => $item['color_back'] ?? '#fefefe',
      ];
      $form['settings'][$i]['delete'] = [
        '#type' => 'checkbox',
        '#title' => $this->t('Delete'),
        '#default_value' => FALSE,
      ];
    }

    $form['add'] = [
      '#type' => 'submit',
      '#value' => $this->t('Add new type'),
      '#attributes' => [
        'class' => [
          'button--action',
        ],
      ],
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save configuration'),
      '#attributes' => [
        'class' => [
          'button button--primary',
        ],
      ],
      '#disabled' => count($items) === 0,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $triggering_element = $form_state->getTriggeringElement();
    if ($triggering_element['#id'] == "edit-submit") {
      $configs = [];
      $values = $form_state->getValue('settings', []);
      $deleted = 0;
      foreach ($values as $id => $value) {
        if (isset($value['delete']) && $value['delete'] == 1) {
          $deleted++;
        }
        else {
          // Prepare the config array.
          $configs[$id] = [
            'machine_name' => $value['wrap']['machine_name'],
            'label' => $value['wrap']['label'],
            'color_text' => $value['color_text'] ?? '#000000',
            'color_back' => $value['color_back'] ?? '#fefefe',
            'weight' => $value['weight'],
          ];
        }
      }

      if ($deleted > 0) {
        $this->messenger->addWarning(
          $this->formatPlural($deleted, '@count type was deleted.', '@count types were deleted.')
        );
      }

      $this->state->set(InHelper::IN_STATE_TYPES, $configs);
      $this->messenger->addStatus($this->t('Saved successfully.'));
      // Generated CSS based on set colors.
      $this->renderer->generateCss($configs);
    }
    else {
      $configs = $this->state->get(InHelper::IN_STATE_TYPES, []);
      $configs[] = [
        'machine_name' => '',
        'label' => '',
        'color_text' => '#000000',
        'color_back' => '#fefefe',
        'weight' => 0,
      ];
      $this->state->set(InHelper::IN_STATE_TYPES, $configs);
      $this->messenger->addStatus($this->t('Added new type.'));
    }
  }

  /**
   * Returns the list of type for Important Notifications.
   *
   * @return array
   */
  public static function exists($type) {
    // Load by type

// @todo    dd('exists?', $type);

    return FALSE;
  }

}

==> in-1.0.1.tar.gz: in/src/Form/InSettingsForm.php <==
<?php

namespace Drupal\in\Form;

//use Drupal\Component\Uuid\UuidInterface;
use Drupal\Core\Asset\AssetDumperInterface;
use Drupal\Core\File\FileSystemInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\Core\State\StateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\in\InHelper;
use Drupal\in\InRenderer;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * The config form for the IN module.
 *
 * @package Drupal\in\Form
 */
class InSettingsForm extends FormBase {

  use StringTranslationTrait;

  /**
   * The state service.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * Drupal\Core\Messenger\MessengerInterface definition.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * An asset dumper.
   *
   * @var \Drupal\Core\Asset\AssetDumper
   */
  protected $dumper;

  /**
   * The IN renderer.
   *
   * @var \Drupal\in\InRenderer
   */
  protected $renderer;

  /**
   * Constructs a new InSettingsForm object.
   */
  public function __construct(
    StateInterface $state,
    MessengerInterface $messenger,
    InRenderer $renderer
  ) {
    $this->state = $state;
    $this->messenger = $messenger;
    $this->renderer = $renderer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('state'),
      $container->get('messenger'),
      $container->get('in.renderer')
    );
  }

  /**
   * {@inheritDoc}
   */
  public function getFormId() {
    return 'in_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
//    $this->state->set(InHelper::IN_STATE_TYPES, []);

    $items = $this->state->get(InHelper::IN_STATE_TYPES, []);

//    dd($items);

    if (count($items) > 0) {
      $form['settings'] = [
        '#type' => 'table',
        '#header' => [
          '',
          $this->t('Weight'),
          $this->t('Type label'),
          $this->t('Text color'),
          $this->t('Background color'),
          $this->t('Delete'),
        ],
        '#attributes' => [
          'id' => 'in-config-table',
        ],
        '#tabledrag' => [
          [
            'action' => 'order',
            'relationship' => 'sibling',
            'group' => 'draggable-weight',
          ],
        ],
      ];
    }
    else {
      $form['message'] = [
        '#type' => 'markup',
        '#markup' => '<p>' . t('There are no Important Notifications types yet. Just add a new one.') . '</p>',
      ];
    }

    foreach ($items as $i => $item) {
      $weight = $item['weight'];

      $form['settings'][$i] = [
        'data' => [],
      ];
      $form['settings'][$i]['#attributes']['class'] = ['draggable'];
      $form['settings'][$i]['weight'] = [
        '#type' => 'weight',
        '#title' => t('Weight'),
        '#title_display' => 'invisible',
        '#default_value' => $weight,
        '#attributes' => [
          'class' => [
            'draggable-weight'
          ]
        ],
      ];

      $form['settings'][$i]['wrap'] = [
        '#type' => 'container',
      ];
      $form['settings'][$i]['wrap']['label'] = [
        '#type' => 'textfield',
        '#title' => t('Label'),
        '#title_display' => 'invisible',
        '#required' => TRUE,
        '#default_value' => $item['label'],
      ];
      $form['settings'][$i]['wrap']['machine_name'] = [
        '#type' => 'machine_name',
        '#default_value' => $item['machine_name'],
//        '#disabled' => !isNew(), ??
        '#maxlength' => 64,
        '#description' => $this->t('A unique name for this item. It must only contain lowercase letters, numbers, and underscores.'),
        '#machine_name' => [
          'source' => [
            'settings',
            $i,
            'wrap',
            'label',
          ],
          'exists' => [
            $this,
            'exists',
          ],
        ],
      ];

      $form['settings'][$i]['color_text'] = [
        '#type' => 'color',
        '#title' => $this->t('Text color'),
        '#title_display' => 'invisible',
        '#default_value' => $item['color_text'] ?? '#000000',
      ];
      $form['settings'][$i]['color_back'] = [
        '#type' => 'color',
        '#title' => $this->t('Background color'),
        '#title_display' => 'invisible',
        '#default_value' => $item['color_back'] ?? '#fefefe',
      ];
      $form['settings'][$i]['delete'] = [
        '#type' => 'checkbox',
        '#title' => $this->t('Delete'),
        '#default_value' => FALSE,
      ];
    }

    $form['add'] = [
      '#type' => 'submit',
      '#value' => $this->t('Add new type'),
      '#attributes' => [
        'class' => [
          'button--action',
        ],
      ],
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save configuration'),
      '#attributes' => [
        'class' => [
          'button button--primary',
        ],
      ],
      '#disabled' => count($items) === 0,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $triggering_element = $form_state->getTriggeringElement();
    if ($triggering_element['#id'] == "edit-submit") {
      $configs = [];
      $values = $form_state->getValue('settings', []);
      $deleted = 0;
      foreach ($values as $id => $value) {
        if (isset($value['delete']) && $value['delete'] == 1) {
          $deleted++;
        }
        else {
          // Prepare the config array.
          $configs[$id] = [
            'machine_name' => $value['wrap']['machine_name'],
            'label' => $value['wrap']['label'],
            'color_text' => $value['color_text'] ?? '#000000',
            'color_back' => $value['color_back'] ?? '#fefefe',
            'weight' => $value['weight'],
          ];
        }
      }

      if ($deleted > 0) {
        $this->messenger->addWarning(
          $this->formatPlural($deleted, '@count type was deleted.', '@count types were deleted.')
        );
      }

      $this->state->set(InHelper::IN_STATE_TYPES, $configs);
      $this->messenger->addStatus($this->t('Saved successfully.'));
      // Generated CSS based on set colors.
      $this->renderer->generateCss($configs);
    }
    else {
      $configs = $this->state->get(InHelper::IN_STATE_TYPES, []);
      $configs[] = [
        'machine_name' => '',
        'label' => '',
        'color_text' => '#000000',
        'color_back' => '#fefefe',
        'weight' => 0,
      ];
      $this->state->set(InHelper::IN_STATE_TYPES, $configs);
      $this->messenger->addStatus($this->t('Added new type.'));
    }
  }

  /**
   * Checks existing keys for allowed types for Important Notifications.
   *
   * @param string $type
   *   Type name to check.
   *
   * @return bool
   */
  public function exists($type): bool {
    // Load types and check.
    $configs = $this->state->get(InHelper::IN_STATE_TYPES, []);
    foreach ($configs as $config) {
      if ($type === $config['machine_name']) {
        return TRUE;
      }
    }
    return FALSE;
  }

}
